@@ -4,7 +4,7 @@ data(Adult)
 
 all.equal(Adult, c(Adult[1:100], Adult[-(1:100)]))
 
-ec <- eclat(Adult)
+ec <- eclat(Adult,control=list(verb=FALSE))
 all.equal(ec, c(ec[1:100], ec[-(1:100)]))
 
 
